@@ -7,7 +7,7 @@ from .zodipy import Zodipy
 
 try:
     __version__ = pkg_resources.get_distribution(__name__).version
-except pkg_resources.DistributionNotFound:
+except pkg_resources.DistributionNotFound:  # pragma: no cover
     ...
 
 __all__ = (
